<template>
  <div class="all">
    <div class="kb-content">
      <div class="kb-center" ref="left">
        <div
          class="menu-item"
          v-for="(item, i) in tabList"
          :class="activePage == i ? 'menu-item-active' : ''"
          :key="i"
          @click="openRight(item, i)"
          ref="leftbar"
        >
          <span class="iconfont">{{ item.icon }}</span>
          <span class="title">{{ item.name }}</span>
        </div>
      </div>
      <div class="language-right">
        <div class="lang" v-if="activePage == 0">
          <div class="title">语言列表</div>
          <div
            class="bar"
            v-for="(item, i) in langList"
            :key="i"
            @click="pickLang(item, i)"
          >
            <span class="name">{{ item.Name }}</span>
            <span
              class="icon iconfont"
              style="color: #3d68e1;font-size:18px;"
              v-show="activeLang == item.Lang"
              >&#xe6f1;</span
            >
          </div>
        </div>
        <div class="lang" v-if="activePage == 1">
          <div class="title">键盘布局</div>
          <div
            class="bar"
            v-for="(item, i) in keyboardList"
            :key="i"
            @click="pickKb(item, i)"
          >
            <span class="name">{{ item.name }}</span>
            <span
              class="icon iconfont"
              style="color: #3d68e1;font-size:18px;"
              v-show="activeKb == item.id"
              >&#xe6f1;</span
            >
          </div>
        </div>
      </div>
    </div>
  </div>
</template>

<script>
import {
  getLangs,
  setLang,
  getLang,
  getKeyboardLayouts,
  getCurKeyboardLayout,
  setKeyboardLayout,
} from "@/api/system";

export default {
  data() {
    return {
      activeLang: "",
      activeKb: "",
      langList: [],
      keyboardList: [],
      tabList: [
        { name: "系统语言", icon: "\ue6e8" },
        { name: "键盘管理", icon: "\ue6fe" },
      ],
      activePage: 0,
    };
  },
  mounted() {
    this.fetchLangList();
    this.getCurLang();
    this.fetchKeyBoardList();
    this.getCurKb();
  },
  methods: {
    getCurKb() {
      getCurKeyboardLayout().then((res) => {
        this.activeKb = res.data.keyboard;
      });
    },
    getCurLang() {
      getLang().then((res) => {
        if (res && res.success) {
          this.activeLang = res.data.lang;
        }
      });
    },
    fetchLangList() {
      getLangs().then((res) => {
        if (res && res.success) {
          this.langList = res.data;
        }
      });
    },
    fetchKeyBoardList() {
      getKeyboardLayouts().then((res) => {
        if (res && res.success) {
          this.keyboardList = res.data.slice(0, 5);
        }
      });
    },
    pickLang(item) {
      if (item.Lang==this.activeLang) {
        return
      }
      setLang({
        lang: item.Lang,
      }).then(
        (res) => {
          this.getCurLang();
          this.$message.success(res.data);
        },
        (err) => {
          this.$message.error(err.msg);
        }
      );
    },
    pickKb(item) {
      if (this.activeKb==item.id) {
        return
      }
      setKeyboardLayout({
        layout: item.id,
      }).then(
        (res) => {
          this.getCurKb();
          this.$message.success(res.data);
        },
        (err) => {
          this.$message.error(err.msg);
        }
      );
    },
    openRight(item, i) {
      this.activePage = i;
    },
  },
};
</script>
<style lang="scss">
.all {
  width: 100%;
}

.kb-content {
  height: 100%;
  display: flex;
  flex-direction: row;
  flex: 1;
  flex-basis: auto;
  box-sizing: border-box;
  .kb-center {
    height: 100%;
    width: 280px;
    overflow: auto;
    box-sizing: border-box;
    flex-shrink: 0;
    padding: 10px;
    border-right: 5px solid #f8f8f8;
    .menu-item {
      background-color: #f8f8f8;
      height: 50px;
      margin-bottom: 10px;
      border-radius: 8px;
      line-height: 50px;
      box-sizing: border-box;
      font-size: 14px;
      padding: 0 20px;cursor: pointer;
      display: flex;
      align-items: center;
      .title {
        font-size: 15px;
      }
      .iconfont {
        margin-right: 8px;
        font-size: 18px;
      }
    }
    .menu-item-active {
      background-color: #3d68e1;
      color: white;
    }
    .menu-item:hover {
      background-color: #3d68e1;
      color: white;
    }
  }
  .language-right {
    flex: 1;
    flex-basis: auto;
    overflow: auto;
    box-sizing: border-box;
    position: relative;
    padding: 20px 40px;
    .el-form-item.is-required:not(.is-no-asterisk)
      > .el-form-item__label:before,
    .el-form-item.is-required:not(.is-no-asterisk)
      .el-form-item__label-wrap
      > .el-form-item__label:before {
      display: none;
    }
    .el-select {
      width: 100%;
    }
    .el-form-item {
      margin-bottom: 10px;
      height: 50px;
      background: #f8f8f8;
      padding: 4px 20px;
      -webkit-box-sizing: border-box;
      box-sizing: border-box;
      border-radius: 10px;
      .el-form-item__label {
        text-align: left;
        line-height: 42px;
      }
    }
    .el-form-item__content {
      line-height: 40px;
      position: relative;
      font-size: 14px;
    }
    .ip-input-container {
      max-width: none !important;
    }
    .lang {
      .title {
        height: 30px;
        line-height: 30px;
        font-size: 16px;
        margin-bottom: 10px;
      }
      .bar {
        height: 48px;
        background-color: #f8f8f8;
        border-radius: 10px;
        line-height: 50px;
        box-sizing: border-box;
        padding: 0 20px;
        display: flex;
        justify-content: space-between;
        cursor: pointer;
        margin-bottom: 12px;
        .name{
               font-size: 15px;
        }
      }
      .bar:hover{
            background-color: #e9e9e9;
      }
    }
    .save-btn {
      background-color: #3d68e1;
      width: 240px;
      height: 40px;
      margin: 0 auto;
      border-radius: 10px;
      color: #fff;
      line-height: 40px;
      font-size: 14px;
      margin-top: 20px;
    }
  }
}
</style>
